# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import spaces_pb2 as spaces__pb2


class SpacesStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateSpace = channel.unary_unary(
        '/dialog.Spaces/CreateSpace',
        request_serializer=spaces__pb2.RequestCreateSpace.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpace.FromString,
        )
    self.DeleteSpace = channel.unary_unary(
        '/dialog.Spaces/DeleteSpace',
        request_serializer=spaces__pb2.RequestDeleteSpace.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpace.FromString,
        )
    self.SetTitle = channel.unary_unary(
        '/dialog.Spaces/SetTitle',
        request_serializer=spaces__pb2.RequestSetTitle.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpace.FromString,
        )
    self.SetShortname = channel.unary_unary(
        '/dialog.Spaces/SetShortname',
        request_serializer=spaces__pb2.RequestSetShortname.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpace.FromString,
        )
    self.SetAbout = channel.unary_unary(
        '/dialog.Spaces/SetAbout',
        request_serializer=spaces__pb2.RequestSetAbout.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpace.FromString,
        )
    self.SetAvatar = channel.unary_unary(
        '/dialog.Spaces/SetAvatar',
        request_serializer=spaces__pb2.RequestSetAvatar.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpace.FromString,
        )
    self.LoadSpaces = channel.unary_unary(
        '/dialog.Spaces/LoadSpaces',
        request_serializer=spaces__pb2.RequestLoadSpaces.SerializeToString,
        response_deserializer=spaces__pb2.ResponseLoadSpaces.FromString,
        )
    self.LoadSpaceMembers = channel.unary_stream(
        '/dialog.Spaces/LoadSpaceMembers',
        request_serializer=spaces__pb2.RequestStreamSpaceMembers.SerializeToString,
        response_deserializer=spaces__pb2.SpaceMemberWithPeer.FromString,
        )
    self.Invite = channel.unary_unary(
        '/dialog.Spaces/Invite',
        request_serializer=spaces__pb2.RequestSpaceInvite.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpaceMember.FromString,
        )
    self.Kick = channel.unary_unary(
        '/dialog.Spaces/Kick',
        request_serializer=spaces__pb2.RequestSpaceKick.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpaceMember.FromString,
        )
    self.Leave = channel.unary_unary(
        '/dialog.Spaces/Leave',
        request_serializer=spaces__pb2.RequestSpaceLeave.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpaceMember.FromString,
        )
    self.GetSpaceInviteUrl = channel.unary_unary(
        '/dialog.Spaces/GetSpaceInviteUrl',
        request_serializer=spaces__pb2.RequestGetSpaceInviteUrl.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpaceInviteUrl.FromString,
        )
    self.RevokeSpaceInviteUrl = channel.unary_unary(
        '/dialog.Spaces/RevokeSpaceInviteUrl',
        request_serializer=spaces__pb2.RequestRevokeSpaceInviteUrl.SerializeToString,
        response_deserializer=spaces__pb2.ResponseSpaceInviteUrl.FromString,
        )


class SpacesServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateSpace(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteSpace(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetTitle(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetShortname(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetAbout(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetAvatar(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadSpaces(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadSpaceMembers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Invite(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Kick(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Leave(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetSpaceInviteUrl(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RevokeSpaceInviteUrl(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SpacesServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateSpace': grpc.unary_unary_rpc_method_handler(
          servicer.CreateSpace,
          request_deserializer=spaces__pb2.RequestCreateSpace.FromString,
          response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
      ),
      'DeleteSpace': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteSpace,
          request_deserializer=spaces__pb2.RequestDeleteSpace.FromString,
          response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
      ),
      'SetTitle': grpc.unary_unary_rpc_method_handler(
          servicer.SetTitle,
          request_deserializer=spaces__pb2.RequestSetTitle.FromString,
          response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
      ),
      'SetShortname': grpc.unary_unary_rpc_method_handler(
          servicer.SetShortname,
          request_deserializer=spaces__pb2.RequestSetShortname.FromString,
          response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
      ),
      'SetAbout': grpc.unary_unary_rpc_method_handler(
          servicer.SetAbout,
          request_deserializer=spaces__pb2.RequestSetAbout.FromString,
          response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
      ),
      'SetAvatar': grpc.unary_unary_rpc_method_handler(
          servicer.SetAvatar,
          request_deserializer=spaces__pb2.RequestSetAvatar.FromString,
          response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
      ),
      'LoadSpaces': grpc.unary_unary_rpc_method_handler(
          servicer.LoadSpaces,
          request_deserializer=spaces__pb2.RequestLoadSpaces.FromString,
          response_serializer=spaces__pb2.ResponseLoadSpaces.SerializeToString,
      ),
      'LoadSpaceMembers': grpc.unary_stream_rpc_method_handler(
          servicer.LoadSpaceMembers,
          request_deserializer=spaces__pb2.RequestStreamSpaceMembers.FromString,
          response_serializer=spaces__pb2.SpaceMemberWithPeer.SerializeToString,
      ),
      'Invite': grpc.unary_unary_rpc_method_handler(
          servicer.Invite,
          request_deserializer=spaces__pb2.RequestSpaceInvite.FromString,
          response_serializer=spaces__pb2.ResponseSpaceMember.SerializeToString,
      ),
      'Kick': grpc.unary_unary_rpc_method_handler(
          servicer.Kick,
          request_deserializer=spaces__pb2.RequestSpaceKick.FromString,
          response_serializer=spaces__pb2.ResponseSpaceMember.SerializeToString,
      ),
      'Leave': grpc.unary_unary_rpc_method_handler(
          servicer.Leave,
          request_deserializer=spaces__pb2.RequestSpaceLeave.FromString,
          response_serializer=spaces__pb2.ResponseSpaceMember.SerializeToString,
      ),
      'GetSpaceInviteUrl': grpc.unary_unary_rpc_method_handler(
          servicer.GetSpaceInviteUrl,
          request_deserializer=spaces__pb2.RequestGetSpaceInviteUrl.FromString,
          response_serializer=spaces__pb2.ResponseSpaceInviteUrl.SerializeToString,
      ),
      'RevokeSpaceInviteUrl': grpc.unary_unary_rpc_method_handler(
          servicer.RevokeSpaceInviteUrl,
          request_deserializer=spaces__pb2.RequestRevokeSpaceInviteUrl.FromString,
          response_serializer=spaces__pb2.ResponseSpaceInviteUrl.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Spaces', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import config_sync_pb2 as config__sync__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class ConfigSyncStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetParameters = channel.unary_unary(
        '/dialog.ConfigSync/GetParameters',
        request_serializer=config__sync__pb2.RequestGetParameters.SerializeToString,
        response_deserializer=config__sync__pb2.ResponseGetParameters.FromString,
        )
    self.EditParameter = channel.unary_unary(
        '/dialog.ConfigSync/EditParameter',
        request_serializer=config__sync__pb2.RequestEditParameter.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )


class ConfigSyncServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetParameters(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditParameter(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ConfigSyncServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetParameters': grpc.unary_unary_rpc_method_handler(
          servicer.GetParameters,
          request_deserializer=config__sync__pb2.RequestGetParameters.FromString,
          response_serializer=config__sync__pb2.ResponseGetParameters.SerializeToString,
      ),
      'EditParameter': grpc.unary_unary_rpc_method_handler(
          servicer.EditParameter,
          request_deserializer=config__sync__pb2.RequestEditParameter.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.ConfigSync', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import groups_pb2 as groups__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class GroupsStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.LoadFullGroups = channel.unary_unary(
        '/dialog.Groups/LoadFullGroups',
        request_serializer=groups__pb2.RequestLoadFullGroups.SerializeToString,
        response_deserializer=groups__pb2.ResponseLoadFullGroups.FromString,
        )
    self.LoadMembers = channel.unary_unary(
        '/dialog.Groups/LoadMembers',
        request_serializer=groups__pb2.RequestLoadMembers.SerializeToString,
        response_deserializer=groups__pb2.ResponseLoadMembers.FromString,
        )
    self.CreateGroup = channel.unary_unary(
        '/dialog.Groups/CreateGroup',
        request_serializer=groups__pb2.RequestCreateGroup.SerializeToString,
        response_deserializer=groups__pb2.ResponseCreateGroup.FromString,
        )
    self.EditGroupTitle = channel.unary_unary(
        '/dialog.Groups/EditGroupTitle',
        request_serializer=groups__pb2.RequestEditGroupTitle.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDateMid.FromString,
        )
    self.SetGroupShortname = channel.unary_unary(
        '/dialog.Groups/SetGroupShortname',
        request_serializer=groups__pb2.RequestSetGroupShortname.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.EditGroupAvatar = channel.unary_unary(
        '/dialog.Groups/EditGroupAvatar',
        request_serializer=groups__pb2.RequestEditGroupAvatar.SerializeToString,
        response_deserializer=groups__pb2.ResponseEditGroupAvatar.FromString,
        )
    self.RemoveGroupAvatar = channel.unary_unary(
        '/dialog.Groups/RemoveGroupAvatar',
        request_serializer=groups__pb2.RequestRemoveGroupAvatar.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDateMid.FromString,
        )
    self.EditGroupTopic = channel.unary_unary(
        '/dialog.Groups/EditGroupTopic',
        request_serializer=groups__pb2.RequestEditGroupTopic.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
        )
    self.EditGroupAbout = channel.unary_unary(
        '/dialog.Groups/EditGroupAbout',
        request_serializer=groups__pb2.RequestEditGroupAbout.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
        )
    self.InviteUser = channel.unary_unary(
        '/dialog.Groups/InviteUser',
        request_serializer=groups__pb2.RequestInviteUser.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDateMid.FromString,
        )
    self.LeaveGroup = channel.unary_unary(
        '/dialog.Groups/LeaveGroup',
        request_serializer=groups__pb2.RequestLeaveGroup.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDateMid.FromString,
        )
    self.KickUser = channel.unary_unary(
        '/dialog.Groups/KickUser',
        request_serializer=groups__pb2.RequestKickUser.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDateMid.FromString,
        )
    self.MakeUserAdmin = channel.unary_unary(
        '/dialog.Groups/MakeUserAdmin',
        request_serializer=groups__pb2.RequestMakeUserAdmin.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
        )
    self.GetGroupMemberPermissions = channel.unary_unary(
        '/dialog.Groups/GetGroupMemberPermissions',
        request_serializer=groups__pb2.RequestGetGroupMemberPermissions.SerializeToString,
        response_deserializer=groups__pb2.ResponseGetGroupMemberPermissions.FromString,
        )
    self.TransferOwnership = channel.unary_unary(
        '/dialog.Groups/TransferOwnership',
        request_serializer=groups__pb2.RequestTransferOwnership.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeqDate.FromString,
        )
    self.GetGroupInviteUrl = channel.unary_unary(
        '/dialog.Groups/GetGroupInviteUrl',
        request_serializer=groups__pb2.RequestGetGroupInviteUrl.SerializeToString,
        response_deserializer=groups__pb2.ResponseInviteUrl.FromString,
        )
    self.GetGroupInviteUrlBase = channel.unary_unary(
        '/dialog.Groups/GetGroupInviteUrlBase',
        request_serializer=groups__pb2.RequestGetGroupInviteUrlBase.SerializeToString,
        response_deserializer=groups__pb2.ResponseGetGroupInviteUrlBase.FromString,
        )
    self.RevokeInviteUrl = channel.unary_unary(
        '/dialog.Groups/RevokeInviteUrl',
        request_serializer=groups__pb2.RequestRevokeInviteUrl.SerializeToString,
        response_deserializer=groups__pb2.ResponseInviteUrl.FromString,
        )
    self.JoinGroup = channel.unary_unary(
        '/dialog.Groups/JoinGroup',
        request_serializer=groups__pb2.RequestJoinGroup.SerializeToString,
        response_deserializer=groups__pb2.ResponseJoinGroup.FromString,
        )
    self.JoinGroupByPeer = channel.unary_unary(
        '/dialog.Groups/JoinGroupByPeer',
        request_serializer=groups__pb2.RequestJoinGroupByPeer.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.MakeUserAdminObsolete = channel.unary_unary(
        '/dialog.Groups/MakeUserAdminObsolete',
        request_serializer=groups__pb2.RequestMakeUserAdminObsolete.SerializeToString,
        response_deserializer=groups__pb2.ResponseMakeUserAdminObsolete.FromString,
        )


class GroupsServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def LoadFullGroups(self, request, context):
    """/ deprecated
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoadMembers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateGroup(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditGroupTitle(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetGroupShortname(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditGroupAvatar(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveGroupAvatar(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditGroupTopic(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditGroupAbout(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InviteUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LeaveGroup(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def KickUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MakeUserAdmin(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetGroupMemberPermissions(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TransferOwnership(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetGroupInviteUrl(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetGroupInviteUrlBase(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RevokeInviteUrl(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def JoinGroup(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def JoinGroupByPeer(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MakeUserAdminObsolete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_GroupsServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'LoadFullGroups': grpc.unary_unary_rpc_method_handler(
          servicer.LoadFullGroups,
          request_deserializer=groups__pb2.RequestLoadFullGroups.FromString,
          response_serializer=groups__pb2.ResponseLoadFullGroups.SerializeToString,
      ),
      'LoadMembers': grpc.unary_unary_rpc_method_handler(
          servicer.LoadMembers,
          request_deserializer=groups__pb2.RequestLoadMembers.FromString,
          response_serializer=groups__pb2.ResponseLoadMembers.SerializeToString,
      ),
      'CreateGroup': grpc.unary_unary_rpc_method_handler(
          servicer.CreateGroup,
          request_deserializer=groups__pb2.RequestCreateGroup.FromString,
          response_serializer=groups__pb2.ResponseCreateGroup.SerializeToString,
      ),
      'EditGroupTitle': grpc.unary_unary_rpc_method_handler(
          servicer.EditGroupTitle,
          request_deserializer=groups__pb2.RequestEditGroupTitle.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDateMid.SerializeToString,
      ),
      'SetGroupShortname': grpc.unary_unary_rpc_method_handler(
          servicer.SetGroupShortname,
          request_deserializer=groups__pb2.RequestSetGroupShortname.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'EditGroupAvatar': grpc.unary_unary_rpc_method_handler(
          servicer.EditGroupAvatar,
          request_deserializer=groups__pb2.RequestEditGroupAvatar.FromString,
          response_serializer=groups__pb2.ResponseEditGroupAvatar.SerializeToString,
      ),
      'RemoveGroupAvatar': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveGroupAvatar,
          request_deserializer=groups__pb2.RequestRemoveGroupAvatar.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDateMid.SerializeToString,
      ),
      'EditGroupTopic': grpc.unary_unary_rpc_method_handler(
          servicer.EditGroupTopic,
          request_deserializer=groups__pb2.RequestEditGroupTopic.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
      ),
      'EditGroupAbout': grpc.unary_unary_rpc_method_handler(
          servicer.EditGroupAbout,
          request_deserializer=groups__pb2.RequestEditGroupAbout.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
      ),
      'InviteUser': grpc.unary_unary_rpc_method_handler(
          servicer.InviteUser,
          request_deserializer=groups__pb2.RequestInviteUser.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDateMid.SerializeToString,
      ),
      'LeaveGroup': grpc.unary_unary_rpc_method_handler(
          servicer.LeaveGroup,
          request_deserializer=groups__pb2.RequestLeaveGroup.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDateMid.SerializeToString,
      ),
      'KickUser': grpc.unary_unary_rpc_method_handler(
          servicer.KickUser,
          request_deserializer=groups__pb2.RequestKickUser.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDateMid.SerializeToString,
      ),
      'MakeUserAdmin': grpc.unary_unary_rpc_method_handler(
          servicer.MakeUserAdmin,
          request_deserializer=groups__pb2.RequestMakeUserAdmin.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
      ),
      'GetGroupMemberPermissions': grpc.unary_unary_rpc_method_handler(
          servicer.GetGroupMemberPermissions,
          request_deserializer=groups__pb2.RequestGetGroupMemberPermissions.FromString,
          response_serializer=groups__pb2.ResponseGetGroupMemberPermissions.SerializeToString,
      ),
      'TransferOwnership': grpc.unary_unary_rpc_method_handler(
          servicer.TransferOwnership,
          request_deserializer=groups__pb2.RequestTransferOwnership.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeqDate.SerializeToString,
      ),
      'GetGroupInviteUrl': grpc.unary_unary_rpc_method_handler(
          servicer.GetGroupInviteUrl,
          request_deserializer=groups__pb2.RequestGetGroupInviteUrl.FromString,
          response_serializer=groups__pb2.ResponseInviteUrl.SerializeToString,
      ),
      'GetGroupInviteUrlBase': grpc.unary_unary_rpc_method_handler(
          servicer.GetGroupInviteUrlBase,
          request_deserializer=groups__pb2.RequestGetGroupInviteUrlBase.FromString,
          response_serializer=groups__pb2.ResponseGetGroupInviteUrlBase.SerializeToString,
      ),
      'RevokeInviteUrl': grpc.unary_unary_rpc_method_handler(
          servicer.RevokeInviteUrl,
          request_deserializer=groups__pb2.RequestRevokeInviteUrl.FromString,
          response_serializer=groups__pb2.ResponseInviteUrl.SerializeToString,
      ),
      'JoinGroup': grpc.unary_unary_rpc_method_handler(
          servicer.JoinGroup,
          request_deserializer=groups__pb2.RequestJoinGroup.FromString,
          response_serializer=groups__pb2.ResponseJoinGroup.SerializeToString,
      ),
      'JoinGroupByPeer': grpc.unary_unary_rpc_method_handler(
          servicer.JoinGroupByPeer,
          request_deserializer=groups__pb2.RequestJoinGroupByPeer.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'MakeUserAdminObsolete': grpc.unary_unary_rpc_method_handler(
          servicer.MakeUserAdminObsolete,
          request_deserializer=groups__pb2.RequestMakeUserAdminObsolete.FromString,
          response_serializer=groups__pb2.ResponseMakeUserAdminObsolete.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Groups', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



import grpc
import OpenSSL.crypto
import io
import os

from .internal.bot import InternalBot
from .entity_manager import EntityManager
from .messaging import Messaging
from .updates import Updates
from .users import Users


class DialogBot(object):
    """Main Dialog Bot class.

    """
    def __init__(self, channel, bot_token=None, verbose=False, cert=None, private_key=None, access_dir=None):
        self.internal = InternalBot(channel, verbose=verbose, cert=cert, private_key=private_key, access_dir=access_dir)
        self.user_info = None
        if bot_token:
            self.user_info = self.internal.authorize(bot_token)
        else:
            self.user_info = self.internal.anonymous_authorize()
        self.manager = EntityManager(self.internal)
        self.messaging = Messaging(self.manager, self.internal)
        self.updates = Updates(self.manager, self.internal)
        self.users = Users(self.manager, self.internal)
        print('Bot is ready.')

    @staticmethod
    def get_insecure_bot(endpoint, bot_token, verbose=False):
        """Returns Dialog bot with established gRPC insecure channel.

        :param endpoint: bot's endpoint address
        :param bot_token: bot's token
        :param verbose: verbosity level of functions calling
        :return: Dialog bot instance
        """
        channel = grpc.insecure_channel(endpoint)
        return DialogBot(channel, bot_token, verbose=verbose)

    @staticmethod
    def get_secure_bot(endpoint, credentials, bot_token, verbose=False):
        """Returns Dialog bot with established gRPC insecure channel.

        :param endpoint: bot's endpoint address
        :param credentials: SSL credentials
        :param bot_token: bot's token
        :param verbose: verbosity level of functions calling
        :return: Dialog bot instance
        """
        channel = grpc.secure_channel(endpoint, credentials)
        return DialogBot(channel, bot_token, verbose=verbose)

    @staticmethod
    def get_secure_bot_with_pfx_certificate(endpoint, pfx_certificate, pfx_password, verbose=False, access_dir=None):
        pfx1 = open(pfx_certificate, 'rb').read()
        p12 = OpenSSL.crypto.load_pkcs12(pfx1, pfx_password)

        private_key = io.BytesIO()
        cert = io.BytesIO()

        private_key.write(OpenSSL.crypto.dump_privatekey(OpenSSL.crypto.FILETYPE_PEM, p12.get_privatekey()))
        cert.write(OpenSSL.crypto.dump_certificate(OpenSSL.crypto.FILETYPE_PEM, p12.get_certificate()))

        private_key.seek(0)
        cert.seek(0)

        channel = grpc.secure_channel(
            endpoint,
            grpc.ssl_channel_credentials(
                root_certificates=None,
                private_key=private_key.read(),
                certificate_chain=cert.read()
            )
        )

        private_key.seek(0)
        cert.seek(0)

        return DialogBot(channel, verbose=verbose, cert=cert.read(), private_key=private_key.read(), access_dir=access_dir)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import sequence_and_updates_pb2 as sequence__and__updates__pb2


class SequenceAndUpdatesStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetState = channel.unary_unary(
        '/dialog.SequenceAndUpdates/GetState',
        request_serializer=sequence__and__updates__pb2.RequestGetState.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.GetDifference = channel.unary_unary(
        '/dialog.SequenceAndUpdates/GetDifference',
        request_serializer=sequence__and__updates__pb2.RequestGetDifference.SerializeToString,
        response_deserializer=sequence__and__updates__pb2.ResponseGetDifference.FromString,
        )
    self.GetDialogsDifference = channel.unary_unary(
        '/dialog.SequenceAndUpdates/GetDialogsDifference',
        request_serializer=sequence__and__updates__pb2.RequestGetDialogsDifference.SerializeToString,
        response_deserializer=sequence__and__updates__pb2.ResponseGetDialogsDifference.FromString,
        )
    self.GetReferencedEntitites = channel.unary_unary(
        '/dialog.SequenceAndUpdates/GetReferencedEntitites',
        request_serializer=sequence__and__updates__pb2.RequestGetReferencedEntitites.SerializeToString,
        response_deserializer=sequence__and__updates__pb2.ResponseGetReferencedEntitites.FromString,
        )
    self.SubscribeToOnline = channel.unary_unary(
        '/dialog.SequenceAndUpdates/SubscribeToOnline',
        request_serializer=sequence__and__updates__pb2.RequestSubscribeToOnline.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.SubscribeFromOnline = channel.unary_unary(
        '/dialog.SequenceAndUpdates/SubscribeFromOnline',
        request_serializer=sequence__and__updates__pb2.RequestSubscribeFromOnline.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.SubscribeToGroupOnline = channel.unary_unary(
        '/dialog.SequenceAndUpdates/SubscribeToGroupOnline',
        request_serializer=sequence__and__updates__pb2.RequestSubscribeToGroupOnline.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.SubscribeFromGroupOnline = channel.unary_unary(
        '/dialog.SequenceAndUpdates/SubscribeFromGroupOnline',
        request_serializer=sequence__and__updates__pb2.RequestSubscribeFromGroupOnline.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.SeqUpdates = channel.unary_stream(
        '/dialog.SequenceAndUpdates/SeqUpdates',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=sequence__and__updates__pb2.SeqUpdateBox.FromString,
        )


class SequenceAndUpdatesServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetState(self, request, context):
    """/ Get last seq number
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetDifference(self, request, context):
    """/ Get all update that happens after given seq number
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetDialogsDifference(self, request, context):
    """/ Load all dialogs that changed after given date
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetReferencedEntitites(self, request, context):
    """/ Load some required entities
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SubscribeToOnline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SubscribeFromOnline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SubscribeToGroupOnline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SubscribeFromGroupOnline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SeqUpdates(self, request, context):
    """/ Get stream of the user's updates
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SequenceAndUpdatesServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetState': grpc.unary_unary_rpc_method_handler(
          servicer.GetState,
          request_deserializer=sequence__and__updates__pb2.RequestGetState.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'GetDifference': grpc.unary_unary_rpc_method_handler(
          servicer.GetDifference,
          request_deserializer=sequence__and__updates__pb2.RequestGetDifference.FromString,
          response_serializer=sequence__and__updates__pb2.ResponseGetDifference.SerializeToString,
      ),
      'GetDialogsDifference': grpc.unary_unary_rpc_method_handler(
          servicer.GetDialogsDifference,
          request_deserializer=sequence__and__updates__pb2.RequestGetDialogsDifference.FromString,
          response_serializer=sequence__and__updates__pb2.ResponseGetDialogsDifference.SerializeToString,
      ),
      'GetReferencedEntitites': grpc.unary_unary_rpc_method_handler(
          servicer.GetReferencedEntitites,
          request_deserializer=sequence__and__updates__pb2.RequestGetReferencedEntitites.FromString,
          response_serializer=sequence__and__updates__pb2.ResponseGetReferencedEntitites.SerializeToString,
      ),
      'SubscribeToOnline': grpc.unary_unary_rpc_method_handler(
          servicer.SubscribeToOnline,
          request_deserializer=sequence__and__updates__pb2.RequestSubscribeToOnline.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'SubscribeFromOnline': grpc.unary_unary_rpc_method_handler(
          servicer.SubscribeFromOnline,
          request_deserializer=sequence__and__updates__pb2.RequestSubscribeFromOnline.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'SubscribeToGroupOnline': grpc.unary_unary_rpc_method_handler(
          servicer.SubscribeToGroupOnline,
          request_deserializer=sequence__and__updates__pb2.RequestSubscribeToGroupOnline.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'SubscribeFromGroupOnline': grpc.unary_unary_rpc_method_handler(
          servicer.SubscribeFromGroupOnline,
          request_deserializer=sequence__and__updates__pb2.RequestSubscribeFromGroupOnline.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'SeqUpdates': grpc.unary_stream_rpc_method_handler(
          servicer.SeqUpdates,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=sequence__and__updates__pb2.SeqUpdateBox.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.SequenceAndUpdates', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: counters.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import peers_pb2 as peers__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='counters.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\x0e\x63ounters.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x0bpeers.proto\x1a\x15scalapb/scalapb.proto\"Y\n\x0cUnreadDialog\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x07\x63ounter\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"\xda\x01\n\x0b\x41ppCounters\x12\x42\n\x0eglobal_counter\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12J\n\x16global_dialogs_counter\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\r\x8a\xea\x30\t\n\x07visible\x12;\n\x0eunread_dialogs\x18\x03 \x03(\x0b\x32\x14.dialog.UnreadDialogB\r\x8a\xea\x30\t\n\x07visible\"\x85\x01\n\x15UpdateCountersChanged\x12\x34\n\x08\x63ounters\x18\x01 \x01(\x0b\x32\x13.dialog.AppCountersB\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x02ts\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\x8a\xea\x30\t\n\x07visibleB\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_UNREADDIALOG = _descriptor.Descriptor(
  name='UnreadDialog',
  full_name='dialog.UnreadDialog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.UnreadDialog.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counter', full_name='dialog.UnreadDialog.counter', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=232,
)


_APPCOUNTERS = _descriptor.Descriptor(
  name='AppCounters',
  full_name='dialog.AppCounters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='global_counter', full_name='dialog.AppCounters.global_counter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='global_dialogs_counter', full_name='dialog.AppCounters.global_dialogs_counter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unread_dialogs', full_name='dialog.AppCounters.unread_dialogs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=453,
)


_UPDATECOUNTERSCHANGED = _descriptor.Descriptor(
  name='UpdateCountersChanged',
  full_name='dialog.UpdateCountersChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='counters', full_name='dialog.UpdateCountersChanged.counters', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ts', full_name='dialog.UpdateCountersChanged.ts', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=589,
)

_UNREADDIALOG.fields_by_name['peer'].message_type = peers__pb2._PEER
_APPCOUNTERS.fields_by_name['global_counter'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_APPCOUNTERS.fields_by_name['global_dialogs_counter'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_APPCOUNTERS.fields_by_name['unread_dialogs'].message_type = _UNREADDIALOG
_UPDATECOUNTERSCHANGED.fields_by_name['counters'].message_type = _APPCOUNTERS
_UPDATECOUNTERSCHANGED.fields_by_name['ts'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['UnreadDialog'] = _UNREADDIALOG
DESCRIPTOR.message_types_by_name['AppCounters'] = _APPCOUNTERS
DESCRIPTOR.message_types_by_name['UpdateCountersChanged'] = _UPDATECOUNTERSCHANGED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UnreadDialog = _reflection.GeneratedProtocolMessageType('UnreadDialog', (_message.Message,), dict(
  DESCRIPTOR = _UNREADDIALOG,
  __module__ = 'counters_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UnreadDialog)
  ))
_sym_db.RegisterMessage(UnreadDialog)

AppCounters = _reflection.GeneratedProtocolMessageType('AppCounters', (_message.Message,), dict(
  DESCRIPTOR = _APPCOUNTERS,
  __module__ = 'counters_pb2'
  # @@protoc_insertion_point(class_scope:dialog.AppCounters)
  ))
_sym_db.RegisterMessage(AppCounters)

UpdateCountersChanged = _reflection.GeneratedProtocolMessageType('UpdateCountersChanged', (_message.Message,), dict(
  DESCRIPTOR = _UPDATECOUNTERSCHANGED,
  __module__ = 'counters_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateCountersChanged)
  ))
_sym_db.RegisterMessage(UpdateCountersChanged)


DESCRIPTOR._options = None
_UNREADDIALOG.fields_by_name['peer']._options = None
_UNREADDIALOG.fields_by_name['counter']._options = None
_APPCOUNTERS.fields_by_name['global_counter']._options = None
_APPCOUNTERS.fields_by_name['global_dialogs_counter']._options = None
_APPCOUNTERS.fields_by_name['unread_dialogs']._options = None
_UPDATECOUNTERSCHANGED.fields_by_name['counters']._options = None
_UPDATECOUNTERSCHANGED.fields_by_name['ts']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import typing_and_online_pb2 as typing__and__online__pb2


class TypingAndOnlineStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Typing = channel.unary_unary(
        '/dialog.TypingAndOnline/Typing',
        request_serializer=typing__and__online__pb2.RequestTyping.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.StopTyping = channel.unary_unary(
        '/dialog.TypingAndOnline/StopTyping',
        request_serializer=typing__and__online__pb2.RequestStopTyping.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.SetOnline = channel.unary_unary(
        '/dialog.TypingAndOnline/SetOnline',
        request_serializer=typing__and__online__pb2.RequestSetOnline.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.PauseNotifications = channel.unary_unary(
        '/dialog.TypingAndOnline/PauseNotifications',
        request_serializer=typing__and__online__pb2.RequestPauseNotifications.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )
    self.RestoreNotifications = channel.unary_unary(
        '/dialog.TypingAndOnline/RestoreNotifications',
        request_serializer=typing__and__online__pb2.RequestRestoreNotifications.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
        )


class TypingAndOnlineServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Typing(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def StopTyping(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetOnline(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PauseNotifications(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RestoreNotifications(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TypingAndOnlineServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Typing': grpc.unary_unary_rpc_method_handler(
          servicer.Typing,
          request_deserializer=typing__and__online__pb2.RequestTyping.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'StopTyping': grpc.unary_unary_rpc_method_handler(
          servicer.StopTyping,
          request_deserializer=typing__and__online__pb2.RequestStopTyping.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'SetOnline': grpc.unary_unary_rpc_method_handler(
          servicer.SetOnline,
          request_deserializer=typing__and__online__pb2.RequestSetOnline.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'PauseNotifications': grpc.unary_unary_rpc_method_handler(
          servicer.PauseNotifications,
          request_deserializer=typing__and__online__pb2.RequestPauseNotifications.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
      'RestoreNotifications': grpc.unary_unary_rpc_method_handler(
          servicer.RestoreNotifications,
          request_deserializer=typing__and__online__pb2.RequestRestoreNotifications.FromString,
          response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.TypingAndOnline', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="dialog-bot-sdk",
    version="2.1.6",
    author="Andrey Skiba, Dialog LLC",
    author_email="a.skiba@dlg.im",
    description="Python Bot SDK for Dialog Messenger",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dialogs/python-bot-sdk",
    packages=setuptools.find_packages(),
    license='Apache License 2.0',
    keywords='dialog messenger bot sdk',
    install_requires=[
        'protobuf',
        'google-api-python-client',
        'googleapis-common-protos',
        'gevent',
        'grpcio',
        'grpcio-tools',
        'requests',
        'pyopenssl',
        'Pillow'
    ],
    python_requires='>=3',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import profile_pb2 as profile__pb2


class ProfileStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.EditName = channel.unary_unary(
        '/dialog.Profile/EditName',
        request_serializer=profile__pb2.RequestEditName.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.EditNickName = channel.unary_unary(
        '/dialog.Profile/EditNickName',
        request_serializer=profile__pb2.RequestEditNickName.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.CheckNickName = channel.unary_unary(
        '/dialog.Profile/CheckNickName',
        request_serializer=profile__pb2.RequestCheckNickName.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseBool.FromString,
        )
    self.EditAbout = channel.unary_unary(
        '/dialog.Profile/EditAbout',
        request_serializer=profile__pb2.RequestEditAbout.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.EditAvatar = channel.unary_unary(
        '/dialog.Profile/EditAvatar',
        request_serializer=profile__pb2.RequestEditAvatar.SerializeToString,
        response_deserializer=profile__pb2.ResponseEditAvatar.FromString,
        )
    self.RemoveAvatar = channel.unary_unary(
        '/dialog.Profile/RemoveAvatar',
        request_serializer=profile__pb2.RequestRemoveAvatar.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.EditMyTimeZone = channel.unary_unary(
        '/dialog.Profile/EditMyTimeZone',
        request_serializer=profile__pb2.RequestEditMyTimeZone.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.EditMyPreferredLanguages = channel.unary_unary(
        '/dialog.Profile/EditMyPreferredLanguages',
        request_serializer=profile__pb2.RequestEditMyPreferredLanguages.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.EditSex = channel.unary_unary(
        '/dialog.Profile/EditSex',
        request_serializer=profile__pb2.RequestEditSex.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.EditCustomProfile = channel.unary_unary(
        '/dialog.Profile/EditCustomProfile',
        request_serializer=profile__pb2.RequestEditCustomProfile.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )
    self.ChangeUserStatus = channel.unary_unary(
        '/dialog.Profile/ChangeUserStatus',
        request_serializer=profile__pb2.RequestChangeUserStatus.SerializeToString,
        response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
        )


class ProfileServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def EditName(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditNickName(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CheckNickName(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditAbout(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditAvatar(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveAvatar(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditMyTimeZone(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditMyPreferredLanguages(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditSex(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EditCustomProfile(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ChangeUserStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ProfileServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'EditName': grpc.unary_unary_rpc_method_handler(
          servicer.EditName,
          request_deserializer=profile__pb2.RequestEditName.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'EditNickName': grpc.unary_unary_rpc_method_handler(
          servicer.EditNickName,
          request_deserializer=profile__pb2.RequestEditNickName.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'CheckNickName': grpc.unary_unary_rpc_method_handler(
          servicer.CheckNickName,
          request_deserializer=profile__pb2.RequestCheckNickName.FromString,
          response_serializer=miscellaneous__pb2.ResponseBool.SerializeToString,
      ),
      'EditAbout': grpc.unary_unary_rpc_method_handler(
          servicer.EditAbout,
          request_deserializer=profile__pb2.RequestEditAbout.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'EditAvatar': grpc.unary_unary_rpc_method_handler(
          servicer.EditAvatar,
          request_deserializer=profile__pb2.RequestEditAvatar.FromString,
          response_serializer=profile__pb2.ResponseEditAvatar.SerializeToString,
      ),
      'RemoveAvatar': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveAvatar,
          request_deserializer=profile__pb2.RequestRemoveAvatar.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'EditMyTimeZone': grpc.unary_unary_rpc_method_handler(
          servicer.EditMyTimeZone,
          request_deserializer=profile__pb2.RequestEditMyTimeZone.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'EditMyPreferredLanguages': grpc.unary_unary_rpc_method_handler(
          servicer.EditMyPreferredLanguages,
          request_deserializer=profile__pb2.RequestEditMyPreferredLanguages.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'EditSex': grpc.unary_unary_rpc_method_handler(
          servicer.EditSex,
          request_deserializer=profile__pb2.RequestEditSex.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'EditCustomProfile': grpc.unary_unary_rpc_method_handler(
          servicer.EditCustomProfile,
          request_deserializer=profile__pb2.RequestEditCustomProfile.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
      'ChangeUserStatus': grpc.unary_unary_rpc_method_handler(
          servicer.ChangeUserStatus,
          request_deserializer=profile__pb2.RequestChangeUserStatus.FromString,
          response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Profile', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import integrations_pb2 as integrations__pb2


class IntegrationsStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetIntegrationToken = channel.unary_unary(
        '/dialog.Integrations/GetIntegrationToken',
        request_serializer=integrations__pb2.RequestGetIntegrationToken.SerializeToString,
        response_deserializer=integrations__pb2.ResponseIntegrationToken.FromString,
        )
    self.RevokeIntegrationToken = channel.unary_unary(
        '/dialog.Integrations/RevokeIntegrationToken',
        request_serializer=integrations__pb2.RequestRevokeIntegrationToken.SerializeToString,
        response_deserializer=integrations__pb2.ResponseIntegrationToken.FromString,
        )


class IntegrationsServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetIntegrationToken(self, request, context):
    """/ Get token for posting to group
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RevokeIntegrationToken(self, request, context):
    """/ Revoke token
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_IntegrationsServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetIntegrationToken': grpc.unary_unary_rpc_method_handler(
          servicer.GetIntegrationToken,
          request_deserializer=integrations__pb2.RequestGetIntegrationToken.FromString,
          response_serializer=integrations__pb2.ResponseIntegrationToken.SerializeToString,
      ),
      'RevokeIntegrationToken': grpc.unary_unary_rpc_method_handler(
          servicer.RevokeIntegrationToken,
          request_deserializer=integrations__pb2.RequestRevokeIntegrationToken.FromString,
          response_serializer=integrations__pb2.ResponseIntegrationToken.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dialog.Integrations', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
